==> iReport-1.1.0-src.zip: iReport-1.1.0-src/src/it/businesslogic/ireport/chart/PieDataset.java <==
/*
 * PieDataset.java
 *
 * Created on 15 agosto 2005, 17.49
 *
 * To change this template, choose Tools | Options and locate the template under
 * the Source Creation and Management node. Right-click the template and choose
 * Open. You can then make changes to the template in the Source Editor.
 */

package it.businesslogic.ireport.chart;

/**
 *
 * @author Administrator
 */
public class PieDataset extends Dataset {
    
    private String keyExpression = "";
    private String valueExpression = "";
    private String labelExpression = "";
        
    /** Creates a new instance of PieDataset */
    public PieDataset() {
        super();
    }

    public String getKeyExpression() {
        return keyExpression;
    }

    public void setKeyExpression(String keyExpression) {
        this.keyExpression = keyExpression;
    }

    public String getValueExpression() {
        return valueExpression;
    }

    public void setValueExpression(String valueExpression) {
        this.valueExpression = valueExpression;
    }

    public String getLabelExpression() {
        return labelExpression;
    }

    public void setLabelExpression(String labelExpression) {
        this.labelExpression = labelExpression;
    }
    
    public Dataset cloneMe()
    {
        PieDataset obj = new PieDataset();
        copyBaseDataset(obj);
        obj.setLabelExpression(getLabelExpression());
        obj.setKeyExpression( getKeyExpression());
        obj.setValueExpression( getValueExpression());

        
        return obj;
    }  
    
}

==> iReport-1.2.6-src.zip: iReport-1.2.6-src/src/it/businesslogic/ireport/chart/PieDataset.java <==
/*
 * PieDataset.java
 *
 * Created on 15 agosto 2005, 17.49
 *
 * To change this template, choose Tools | Options and locate the template under
 * the Source Creation and Management node. Right-click the template and choose
 * Open. You can then make changes to the template in the Source Editor.
 */

package it.businesslogic.ireport.chart;

/**
 *
 * @author Administrator
 */
public class PieDataset extends Dataset {
    
    private String keyExpression = "";
    private String valueExpression = "";
    private String labelExpression = "";
    
    private SectionItemHyperlink sectionHyperLink = new SectionItemHyperlink();
        
    /** Creates a new instance of PieDataset */
    public PieDataset() {
        super();
    }

    public String getKeyExpression() {
        return keyExpression;
    }

    public void setKeyExpression(String keyExpression) {
        this.keyExpression = keyExpression;
    }

    public String getValueExpression() {
        return valueExpression;
    }

    public void setValueExpression(String valueExpression) {
        this.valueExpression = valueExpression;
    }

    public String getLabelExpression() {
        return labelExpression;
    }

    public void setLabelExpression(String labelExpression) {
        this.labelExpression = labelExpression;
    }
    
    public Dataset cloneMe()
    {
        PieDataset obj = new PieDataset();
        copyBaseDataset(obj);
        obj.setLabelExpression(getLabelExpression());
        obj.setKeyExpression( getKeyExpression());
        obj.setValueExpression( getValueExpression());
        obj.setSectionHyperLink( getSectionHyperLink().cloneMe());
        
        return obj;
    }  

    public SectionItemHyperlink getSectionHyperLink() {
        return sectionHyperLink;
    }

    public void setSectionHyperLink(SectionItemHyperlink secionHyperLink) {
        this.sectionHyperLink = secionHyperLink;
    }
    
}
